@@ -37,7 +37,7 @@
 #include "plugin.h"
 #include "obex.h"
 #include "service.h"
-#include "logging.h"
+#include "log.h"
 #include "dbus.h"
 
 #define VCARD_TYPE "text/x-vcard"
@@ -140,6 +140,9 @@ skip_auth:
 	if (name == NULL || strlen(name) == 0)
 		return -EBADR;
 
+	if (g_strcmp0(name, obex_get_name(os)) != 0)
+		obex_set_name(os, name);
+
 	path = g_build_filename(folder, name, NULL);
 
 	manager_emit_transfer_started(os);
